
# widget-jsmol

A Jupyter widget to use Jmol/Jsmol.

## Try it on Binder

[![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/osscar-org/widget-jsmol/master?urlpath=%2Flab%2Ftree%2Fexamples%2Fintroduction.ipynb)

## Installation

You can install using `pip`:

```bash
pip install widget_jsmol
```

Or if you use jupyterlab:

```bash
pip install widget_jsmol
jupyter labextension install @osscar/widget_jsmol
```

If you are using Jupyter Notebook 5.2 or earlier, you may also need to enable
the nbextension:
```bash
jupyter nbextension enable --py [--sys-prefix|--user|--system] widget_jsmol
```

## [Usage of this widget ](./USAGE.md)



# Acknowlegements

We acknowledge support from:
* EPFL Open Science Fund

<img src='/images/OSSCAR-logo.png' width='350'>
